@@ -14,8 +14,8 @@ class AsyncEndpoint:
 
 
 class BlocksChildrenAsyncEndpoint(AsyncEndpoint):
-    async def append(self, block_id: str, **kwargs) -> Block:
-        return parse_block_obj(
+    async def append(self, block_id: str, **kwargs) -> PaginatedList[Block]:
+        return PaginatedList[Block].parse_obj(
             await self.client.request(
                 path="blocks/{id}/children".format(id=block_id),
                 method="PATCH",
@@ -76,7 +76,7 @@ class DatabasesAsyncEndpoint(AsyncEndpoint):
                 method="POST",
                 path="/databases",
                 auth=kwargs.get("auth", None),
-                query=pick(kwargs, "start_cursor"),
+                body=pick(kwargs, "parent", "properties", "children", "icon", "cover"),
             )
         )
 
@@ -109,6 +109,16 @@ class DatabasesAsyncEndpoint(AsyncEndpoint):
             )
         )
 
+    async def update(self, database_id: str, **kwargs) -> Database:
+        return Database.parse_obj(
+            await self.client.request(
+                method="PATCH",
+                path="/databases/{id}".format(id=database_id),
+                auth=kwargs.get("auth", None),
+                body=pick(kwargs, "properties", "title", "icon", "cover"),
+            )
+        )
+
 
 class PagesAsyncEndpoint(AsyncEndpoint):
     async def create(self, **kwargs) -> Page:
@@ -117,7 +127,7 @@ class PagesAsyncEndpoint(AsyncEndpoint):
                 method="POST",
                 path="/pages",
                 auth=kwargs.get("auth", None),
-                body=pick(kwargs, "parent", "properties", "children"),
+                body=pick(kwargs, "parent", "properties", "children", "cover", "icon"),
             )
         )
 
@@ -136,7 +146,7 @@ class PagesAsyncEndpoint(AsyncEndpoint):
                 method="PATCH",
                 path="pages/{id}".format(id=page_id),
                 auth=kwargs.get("auth", None),
-                body=pick(kwargs, "archived", "properties"),
+                body=pick(kwargs, "archived", "properties", "cover", "icon"),
             )
         )
 
